<!--隐患查询-->
<template>
  <div style="height:100%" class="mobile-device">
    <!--  头部  -->
    <van-sticky>
      <van-nav-bar
        title="隐患查询"
        left-arrow
        @click-left="_ => $router.go(-1)"
        @click-right="showPopup('querySearchPopup')"
      >
        <template #right>
          <van-icon name="search" size="18" />
        </template>
      </van-nav-bar>
    </van-sticky>

    <div class="mobile-content">
      <van-pull-refresh
        v-model="refreshing"
        @refresh="onRefresh"
        class="van-hairline--top"
      >
        <van-list
          v-model="loading"
          :finished="finished"
          finished-text="没有更多了"
          @load="onLoad"
          :immediate-check="false"
        >
          <div
            v-for="(item, index) in listData"
            :key="index"
            class="device van-hairline--bottom"
            :class="{myStyle: index === listData.length - 1}"
            @click="showPopup('modifyPopup',item)"
          >
            <div class="device-item">
              <div class="device-item-text">
                <div class="device-item-content" style="margin-bottom: 6px">
                  <div>
                    <div class="device-name">
                      {{ item.unitName }}
                    </div>
                  </div>
                  <div class="device-status">
                    <van-tag
                      :type="dictionaryEscape(expireStatusOpt, item.expireStatus, {labelKey: 'type'})"
                    >
                      {{ dictionaryEscape(expireStatusOpt, item.expireStatus) }}
                    </van-tag>
                  </div>
                </div>
              </div>
              <div class="device-content">
                <p>
                  <span style="color:#333">受检单位名称：</span
                  >{{ item.unitName }}
                </p>
                <p>
                  <span style="color:#333">受检单位类别：</span>
                  {{ dictionaryEscape(unitsTypeOpt, item.type) }}
                </p>
                <p>
                  <span style="color:#333">排查时间：</span
                  >{{ item.checkDate }}
                </p>
                <p>
                  <span style="color:#333">最迟复查时间：</span
                  >{{ item.latestReviewDate }}
                </p>
                <p>
                  <span style="color:#333">隐患内容：</span
                  >{{ item.dangerContent }}
                </p>
              </div>
            </div>
            <!-- -1：报废，1：正常、2：故障、9：其他） -->
          </div>
        </van-list>
      </van-pull-refresh>
    </div>

    <ModifyPopup
      ref="modifyPopup"
      :modifyPopup.sync="modifyPopup"
      :rowInfo="rowInfo"
      @changeData="changeData"
    />

    <!-- 列表筛选弹层 -->
    <QuerySearchPopup
      :querySearchPopup.sync="querySearchPopup"
      :customQueryPrams="customQueryPrams"
      :expireStatusOpt="expireStatusOpt"
      :unitsTypeOpt="unitsTypeOpt"
      :statusOpt="statusOpt"
      @searchData="searchData"
    />
  </div>
</template>

<script>
import CmgtSaftyDangerCheckrecordApi from '@/views/Manage/saftyDanger/api/CmgtSaftyDangerCheckrecordApi'
import productManage from '@/api/device/productManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import ModifyPopup from '@/views/Mobile/Manage/MobileSaftyDanger/components/ModifyPopup/index.vue'
import QuerySearchPopup from './components/QuerySearchPopup/index.vue'

const {CSaftyDangerAbarbeitungList} = CmgtSaftyDangerCheckrecordApi

export default {
  name: 'MobileSaftyDanger',
  components: {QuerySearchPopup, ModifyPopup},
  // 隐患查询
  data() {
    return {
      listData: [], // 列表数据
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.handleStatus', // 处理状态
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.expireStatus',   // 超期状态
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 't.type', // 受检单位类别
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 't.unitName', // 受检单位名称
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'BETWEEN',
          parentGroup: '',
          property: 't.latestReviewDate', // 排查时间
          relation: 'AND',
          value: ''
        }
      ],
      // 自定义请求参数配置对象
      customQueryPrams: {
        pageSize: 10,
        page: 1,
        't.expireStatus': '',
        't.handleStatus': '',
        't.type': '',
        't.unitName': '',
        't.latestReviewDate': ''
      },
      // 超期状态配置数组对象
      expireStatusOpt: [
        {text: '全部', value: '', type: 'primary'},
        {text: '正常', value: '1', type: 'success'},
        {text: '临期', value: '2', type: 'warning'},
        {text: '超期', value: '3', type: 'danger'}
      ],
      // 受检单位配置数组对象
      unitsTypeOpt: [
        {text: '所有受检单位', value: ''},
        ...dictUtils.getDictItemsFromCache('zhgl-dwlx').map(i => {
          return {text: i.name, value: i.value}
        })
      ],
      // 超期状态配置数组对象
      statusOpt: [
        {text: '所有', value: '', type: 'primary'},
        {text: '待排查', value: '1', type: 'danger'},
        {text: '整改中', value: '2', type: 'warning'},
        {text: '已完成', value: '3', type: 'success'}
      ],
      loading: false,
      finished: false,
      refreshing: false,
      modifyPopup: false, // 修改弹层
      querySearchPopup: false, // 搜索弹层
      rowInfo: {} // 点击行信息
    }
  },
  computed: {
    // 加工为后端需要的请求格式
    queryParams() {
      const {pageSize, page, ...item} = this.customQueryPrams
      /*
      * 定义 escapeOpt 字段对应字典名 对象，后续进行字段的翻译逻辑
      *  为重新加工结构赋值的新请求配置参数
      * */
      const escapeOpt = {
        't.handleStatus': 'statusOpt',
        't.expireStatus': 'expireStatusOpt',
        't.type': 'unitsTypeOpt'
      }
      return {
        pageBean: {pageSize, page},
        querys: this.querys.map(i => {
          let value = item[i.property]
          let escape = this[escapeOpt[i.property]]
          if (escape) {
            value = this.dictionaryEscape(escape, value, {dictionaryType: false})
            return {...i, value}
          } else {
            if (i.property === 't.latestReviewDate') {
              value = value === '' ? '' : value.split(' ~ ')
              return {...i, value}
            }
            return {...i, value}
          }
        })
      }
    }
  },
  created() {
    this.getListData() // 获取列表数据
  },
  methods: {
    // 字典转义(转义、翻译)
    dictionaryEscape(dictionary, val, option = {}) {
      if (!(Array.isArray(dictionary) && dictionary.length)) return ''
      option = {
        valueKey: 'value',
        labelKey: 'text',
        dictionaryType: true,// true 为转义 false 为翻译
        ...option
      }
      const {valueKey, labelKey, dictionaryType} = option
      let item = dictionary.find(i => i[dictionaryType ? valueKey : labelKey] === val) || {}
      return item[dictionaryType ? labelKey : valueKey] || ''
    },

    // 触底时触发
    onLoad() {
      this.customQueryPrams.page++
      this.getListData(_ => this.loading = false)
    },

    // 下拉时触发
    onRefresh() {
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData(_ => this.refreshing = false)
    },

    // 获取列表数据
    async getListData(callback) {
      const {data: {value: {rows, total}}} = await CSaftyDangerAbarbeitungList(this.queryParams)
      const {pageSize, page} = this.customQueryPrams
      this.listData = this.listData.concat(rows)
      this.$nextTick(_ => callback && callback())
      if (pageSize * page >= total) this.finished = true
    },

    // 打开弹层
    showPopup(popupName, rowInfo) {
      // 复制数据
      if (
        Object.prototype.toString.call(rowInfo) === '[object Object]' &&
        Object.keys(rowInfo).length) {
        this.rowInfo = rowInfo
      }

      switch (popupName) {
        case 'querySearchPopup' :
          this[popupName] = true
          break
        case 'modifyPopup' :
          const {modifyPopup} = this.$refs
          modifyPopup.getDetail(rowInfo, _ => this[popupName] = true)
          break
      }
    },

    // 改变数据
    changeData(rowInfo) {
      const {modifyPopup} = this.$refs
      modifyPopup.getDetail(rowInfo, newRowInfo => {
        let index = this.listData.findIndex(i => i.id === newRowInfo.id)
        this.listData.splice(index, 1, newRowInfo)
        this.modifyPopup = false
      })
    },

    // 查询/重置按钮点击
    searchData() {
      this.finished = false
      this.customQueryPrams.page = 1
      this.listData = []
      this.getListData()
    }

  }
}
</script>

<style lang="scss" scoped>
@import '@/assets/css/element-variables';

.van-cell__title span,
.van-cell__value span {
  font-size: 82px;
}

.van-cell__value span {
  color: $--mobile-text-active;
}

::v-deep .van-tabs__nav {
  background-color: #f9f9f9;
}

::v-deep .device .device-item-text[data-v-177731b7] {
  border-bottom: 0;
}

::v-deep .van-hairline--top::after {
  border-top-width: 0px;
}

::v-deep .van-popup {
  background-color: #f9f9f9;
}

.search-box {
  width: 100%;
  z-index: 10;
  // padding-top: 200px;
}

::v-deep .el-upload--picture-card {
  width: 350px !important;
  height: 350px !important;
  line-height: 350px !important;
}

::v-deep .el-upload-list--picture-card .el-upload-list__item {
  width: 350px !important;
  height: 350px !important;
}

.trouble-content {
  padding: 60px;
}

.popup-content {
  height: 86%;
  overflow-y: scroll;
}

.confirm-button {
  width: 90%;
  position: fixed;
  bottom: 20px;
  display: flex;
  justify-content: space-evenly;
}

::v-deep .search-box {
  display: flex;
  justify-content: space-between;
  width: 100%;
  z-index: 10;

  .van-dropdown-menu {
    width: 100%;

    .van-dropdown-menu__bar {
      box-shadow: 0 2px 12px rgba(255, 255, 255, 0.12);
    }
  }

  // .van-search {
  //   flex: 1;
  // }
}

//  ::v-deep .van-dropdown-item {
//   top: 228px !important;
// }
.mobile-content {
  height: 80%;
  background-color: #f9f9f9;
}

.device {
  background-color: #f9f9f9;
  padding: 40px 40px 20px 40px;
  box-sizing: border-box;
  color: $--mobile-text-sub;
  width: 100%;

  .device-item {
    background-color: #fff;
    border-radius: 60px;
    padding: 20px 100px 20px 100px;
    box-shadow: 0 4px 8px 0 rgba(0, 0, 0, 0.1), 0 6px 20px 0 rgba(0, 0, 0, 0.1);

  }

  .device-content {
    // padding: 50px 0px 50px 0px;
    // height: 400px;
    font-size: 50px;

    p {
      margin: 10px 0 10px 0;
    }
  }

  .device-item-img {
    width: 256px;
    height: 256px;

    img {
      width: 100%;
      height: 100%;
    }
  }

  .device-item-text {
    padding: 20px 0px 20px 0px;
    // margin-left: 10px;
    // width: calc(100% - 256px - 10px);
    border-bottom: 1px solid #dedddd;
  }

  .device-item-content {
    display: flex;
    justify-content: space-between;
    align-items: center;

    span {
      font-size: 72px;
    }
  }

  .device-name {
    font-size: 72px;
    color: $--mobile-text-main;
  }

  .device-name-icon {
    color: $-mobile-primary;
    margin-right: 2px;
  }

  .device-code {
    color: $--mobile-text-sub;
    font-size: 82px;
  }

  .device-item-title {
    color: #49a1f9;
    margin-right: 2px;
  }

  .device-status .van-tag {
    // padding: 4px 6px;
    width: 150px;
    border-radius: 5px;
    padding: 15px 20px;
    font-size: 60px;
    text-align: center;
    color: white;
  }

  .van-tag {
    width: 200px;
    display: flex;
    justify-content: center;
  }
}

.myStyle {
  padding: 40px 40px 40px 40px;
}
</style>
<style lang="scss">
@import '@/assets/css/vant-custom';
</style>
